@@ -1,75 +1,87 @@
-## ----setup, include=FALSE------------------------------------------------
+## ----setup, include=FALSE-----------------------------------------------------
 knitr::opts_chunk$set(comment = ">",fig.height = 4.5, fig.width = 4.5, fig.show = "hold")
 
-## ----library, message = FALSE--------------------------------------------
+## ----library, message = FALSE-------------------------------------------------
 library(rehh)
 
-## ----make_examples, results = 'hide'-------------------------------------
+## ----make_examples, results = 'hide'------------------------------------------
 make.example.files()
 
-## ----map_inp-------------------------------------------------------------
+## ----minimalcodeexample, results = "hide"-------------------------------------
+hh <-                  # data input
+  data2haplohh(
+    hap_file = "bta12_cgu.hap",
+    map_file = "map.inp",
+    chr.name = "12",
+    allele_coding = "map"
+  )
+scan <- scan_hh(hh)    # calculation of EHH and integration
+ihs <- ihh2ihs(scan)   # log ratio for alleles and normalization
+manhattanplot(ihs)     # plot of the statistics
+
+## ----map_inp------------------------------------------------------------------
 # show first 6 lines of file
 cat(readLines("map.inp", n = 6), sep = "\n")
 
-## ----eval = FALSE--------------------------------------------------------
+## ----eval = FALSE-------------------------------------------------------------
 #  ?data2haplohh
 
-## ----example1------------------------------------------------------------
+## ----example1-----------------------------------------------------------------
 hh <- data2haplohh(hap_file = "bta12_cgu.hap",
                    map_file = "map.inp",
                    chr.name = 12,
                    allele_coding = "map")
 
-## ----error = TRUE--------------------------------------------------------
+## ----error = TRUE-------------------------------------------------------------
 hh <- data2haplohh(hap_file = "bta12_cgu.hap",
                    map_file = "map.inp",
                    allele_coding = "map") 
 
-## ----error = TRUE--------------------------------------------------------
+## ----error = TRUE-------------------------------------------------------------
 hh <- data2haplohh(hap_file = "bta12_cgu.hap",
                    map_file = "map.inp",
                    chr.name = 18,
                    allele_coding = "map")
 
-## ----example2------------------------------------------------------------
+## ----example2-----------------------------------------------------------------
 hh <- data2haplohh(hap_file = "bta12_cgu.thap",
                    map_file = "map.inp",
                    chr.name = 12,
                    allele_coding = "map",
                    haplotype.in.columns = TRUE)
 
-## ----example3------------------------------------------------------------
+## ----example3-----------------------------------------------------------------
 hh <- data2haplohh(hap_file = "bta12_hapguess_switch.out",
                    map_file = "map.inp",
                    chr.name = 12,
                    popsel = 7,
                    allele_coding = "map")
 
-## ----error = TRUE--------------------------------------------------------
+## ----error = TRUE-------------------------------------------------------------
 hh <- data2haplohh(hap_file = "bta12_hapguess_switch.out",
                    map_file = "map.inp",
                    chr.name = 12,
                    allele_coding = "map")
 
-## ----vcf_example---------------------------------------------------------
+## ----vcf_example--------------------------------------------------------------
 hh <- data2haplohh(hap_file = "bta12_cgu.vcf.gz",
                    polarize_vcf = FALSE)
 
-## ----ms_example----------------------------------------------------------
+## ----ms_example---------------------------------------------------------------
 hh <- data2haplohh(hap_file = "ms.out",
                    chr.name = 2,
                    position_scaling_factor = 1000)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 hh_subset = subset(hh, select.hap = 1:5, min_maf = 0)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 hh_subset = subset(hh, select.mrk = -1)
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  ?calc_ehh
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 #example haplohh object (280 haplotypes, 1424 SNPs) see ?haplohh_cgu_bta12 for details
 data(haplohh_cgu_bta12)
 #computing EHH statistics for the focal SNP with name "F1205400"
@@ -78,16 +90,16 @@ res <- calc_ehh(haplohh_cgu_bta12,
                 mrk = "F1205400", 
                 include_nhaplo = TRUE)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 res$mrk.name
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 res$freq
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 res$ehh
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 res$ihh
 
 ## ---- ehh, fig.align = 'center', fig.cap = "Graphical output of the plot.ehh() function", fig.pos = '!h', fig.lp = 'fig:'----
@@ -99,25 +111,25 @@ plot(calc_ehh(haplohh_cgu_bta12,
               phased = FALSE),
      xlim = c(2.55E7, 3.05E7))
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  ?calc_ehhs
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 data(haplohh_cgu_bta12)
 res <- calc_ehhs(haplohh_cgu_bta12, 
                  mrk = "F1205400", 
                  include_nhaplo = TRUE)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 res$mrk.name
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 res$ehhs 
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 res$IES
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 res$INES
 
 ## ----ehhs, fig.align = 'center', fig.cap = 'Graphical output of the plot.ehhs() function', fig.pos = '!h', fig.lp = 'fig:'----
@@ -131,21 +143,21 @@ plot(calc_ehhs(haplohh_cgu_bta12,
                mrk = "F1205400",
                phased = FALSE))
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  ?scan_hh
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 data(haplohh_cgu_bta12)
 scan <- scan_hh(haplohh_cgu_bta12)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 scan[453:459,]
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # perform scan using scan_hh
 system.time(scan <- scan_hh(haplohh_cgu_bta12))
 
-## ----slow_scan-----------------------------------------------------------
+## ----slow_scan----------------------------------------------------------------
 # perform scan applying calc_ehh and calc_ehhs to each marker
 slow_scan_hh <- function(haplohh) {
   # create empty vectors of size nmrk
@@ -167,13 +179,13 @@ slow_scan_hh <- function(haplohh) {
 }
 system.time(slow_scan <- slow_scan_hh(haplohh_cgu_bta12))
 
-## ----scancomp------------------------------------------------------------
+## ----scancomp-----------------------------------------------------------------
 identical(slow_scan[, "IHH_A"], scan[, "IHH_A"])
 identical(slow_scan[, "IHH_D"], scan[, "IHH_D"])
 identical(slow_scan[, "IES"], scan[, "IES"])
 identical(slow_scan[, "INES"], scan[, "INES"])
 
-## ----ihh2ihs1, eval = FALSE----------------------------------------------
+## ----ihh2ihs1, eval = FALSE---------------------------------------------------
 #  ## demo code - no data files for all chromosomes provided
 #  for(i in 1:29) {
 #    # haplotype file name for each chromosome
@@ -197,18 +209,18 @@ identical(slow_scan[, "INES"], scan[, "INES"])
 #  # calculate genome-wide iHS values
 #  wgscan.ihs <- ihh2ihs(wgscan)
 
-## ----ihh2ihs2------------------------------------------------------------
+## ----ihh2ihs2-----------------------------------------------------------------
 library(rehh.data)
 data(wgscan.cgu)
 wgscan.ihs.cgu <- ihh2ihs(wgscan.cgu)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 head(wgscan.ihs.cgu$ihs)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 head(wgscan.ihs.cgu$frequency.class)
 
-## ----ines2rsb2-----------------------------------------------------------
+## ----ines2rsb2----------------------------------------------------------------
 data(wgscan.cgu) ; data(wgscan.eut)
 ## results from a genome scan (44,057 SNPs) see ?wgscan.eut and ?wgscan.cgu for details
 rsb.cgu_eut <- ines2rsb(scan_pop1 = wgscan.cgu,
@@ -216,10 +228,10 @@ rsb.cgu_eut <- ines2rsb(scan_pop1 = wgscan.cgu,
                         popname1 = "CGU",
                         popname2 = "EUT")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 head(rsb.cgu_eut)
 
-## ----ies2xpehh2----------------------------------------------------------
+## ----ies2xpehh2---------------------------------------------------------------
 data(wgscan.cgu) ; data(wgscan.eut)
 ## results from a genome scan (44,057 SNPs) see ?wgscan.eut and ?wgscan.cgu for details
 xpehh.cgu_eut <- ies2xpehh(scan_pop1 =  wgscan.cgu,
@@ -227,10 +239,10 @@ xpehh.cgu_eut <- ies2xpehh(scan_pop1 =  wgscan.cgu,
                            popname1 = "CGU",
                            popname2 = "EUT")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 head(xpehh.cgu_eut)
 
-## ----candidate_regions---------------------------------------------------
+## ----candidate_regions--------------------------------------------------------
 cr.cgu <- calc_candidate_regions(wgscan.ihs.cgu,
                                  threshold = 4,
                                  pval = TRUE,
@@ -283,11 +295,13 @@ manhattanplot(wgscan.ihs.cgu,
               threshold = 4, 
               chr.name = c("1", "4", "5", "12"), 
               main = "iHS (CGU cattle breed)", 
-              cr = cr.cgu)
+              cr = cr.cgu,
+              mrk = "F1205400",
+              resolution = c(200000, 0.05))
 # set back to default colors
 palette("default")
 
-## ----rehh2qqman----------------------------------------------------------
+## ----rehh2qqman---------------------------------------------------------------
 # extract data frame from result list
 ihs <- wgscan.ihs.cgu$ihs
 # create new data frame
@@ -309,7 +323,24 @@ manhattan(wgscan.cgu.ihs.qqman,
           highlight = "F1205400",
           annotatePval = 0.0001)
 
-## ------------------------------------------------------------------------
+## ----plothaplo, results = "hide", fig.align = 'center', fig.width = 7, fig.height = 5, fig.lp = 'fig:', fig.cap = 'Graphical output of the plot.haplohh() function', fig.pos = '!h'----
+hh_subset <- subset(haplohh_cgu_bta12, select.mrk = 350:550)
+oldpar <- par(mar = c(3, 2, 2, 2) + 0.1)
+plot(
+  hh_subset,
+  mrk = "F1205400",
+  group_by_allele = TRUE,
+  ignore.distance = TRUE,
+  col = c(NA, "red"),
+  linecol = c("lightblue", "lightpink"),
+  mrk.col = "black",
+  cex = 0.1,
+  pos.lab.hap = "none",
+  pos.lab.mrk = "none"
+)
+par(oldpar)
+
+## -----------------------------------------------------------------------------
 data(haplohh_cgu_bta12)
 furcation <- calc_furcation(haplohh_cgu_bta12,
                             mrk = "F1205400")
@@ -324,7 +355,7 @@ plot(furcation,
      hap.names = hap.names(haplohh_cgu_bta12),
      cex.lab = 0.3)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 newick <- as.newick(furcation,
                     allele = 0,
                     side = "left",
@@ -340,19 +371,19 @@ plot(tree,
      underscore = TRUE,
      no.margin = TRUE)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 haplen <- calc_haplen(furcation)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 haplen$mrk.name
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 haplen$position
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 haplen$xlim
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 head(haplen$haplen)
 
 ## ----haplo, fig.align = 'center', fig.width = 7, fig.height = 7.5, fig.lp = 'fig:', fig.cap = 'Graphical output of the plot.haplen() function', fig.pos = "!h"----
@@ -366,7 +397,7 @@ plot(haplen,
      cex.lab = 0.3,
      legend.xy.coords = "none")
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 # finding the index number of marker "F1205400"
 mrk.nr = which(mrk.names(haplohh_cgu_bta12) == "F1205400")
 # subset of all markers on the "left" of the focal one
@@ -379,6 +410,6 @@ which(duplicated(haplo(hh_left), fromLast = TRUE))
 # extract the corresponding haplotype names
 hap.names(hh_left)[c(236, 248)]
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 remove.example.files()
 
